package App::TouchscreenUtils;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-02-23'; # DATE
our $DIST = 'App-TouchscreenUtils'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: CLI utilities related to touchscreen

__END__

=pod

=encoding UTF-8

=head1 NAME

App::TouchscreenUtils - CLI utilities related to touchscreen

=head1 VERSION

This document describes version 0.002 of App::TouchscreenUtils (from Perl distribution App-TouchscreenUtils), released on 2021-02-23.

=head1 DESCRIPTION

This distribution contains the following CLI utilities related to touchscreen:

=over

=item * L<disable-touchscreen>

=item * L<enable-touchscreen>

=item * L<has-touchscreen>

=item * L<touchscreen-is-enabled>

=item * L<tsoff>

=item * L<tson>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-TouchscreenUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-TouchscreenUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-TouchscreenUtils/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
